==> hermes-2.5.1.61.tar.gz: hermes-2.5.1.61/spec/apis/dmo/logs_spec.rb <==
require 'rails_helper'
require 'faker'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')

  ACCEPTABLE_PARAMS = Hermes::Api::Dmo::LogsController::ACCEPTABLE_PARAMS
  
  RSpec.describe Api::Dmo::LogsController, :type => :api do
    routes {Hermes::Engine.routes}
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper

    let!(:admin) { create(:user, auth_roles: ['superadministrateur']) }
    let!(:score) { create(:score) }
    let!(:score_log) { create(:h_log, code: 'SC_C', action: 'score action', score_id: score.id) }
    let!(:housing_offer) { create(:housing_offer) }
    let!(:housing_offer_log) { create(:h_log, code: 'SC_C', action: 'housing_offer action', housing_offer_id: housing_offer.id) }
    let!(:housing_request) { create(:active_request) }
    let!(:housing_request_log) { create(:h_log, code: 'SC_C', action: 'housing_request action', housing_request_id: housing_request.id) }

    describe 'index' do
      before(:each) do
        authenticated_header(request, admin)
      end

      it 'should return all logs' do
        get :index

        datas = json['data']
        score_ids = datas.map{ |l| l['attributes']['score_id'] }.compact
        housing_offer_ids = datas.map{ |l| l['attributes']['housing_offer_id'] }.compact
        housing_request_ids = datas.map{ |l| l['attributes']['housing_request_id'] }.compact
        expect(score_ids).to include(score.id.to_s)
        expect(housing_offer_ids).to include(housing_offer.id.to_s)
        expect(housing_request_ids).to include(housing_request.id.to_s)
      end

      it 'should return only housing_requests logs' do
        get :housing_requests

        datas = json['data']
        housing_request_ids = datas.map{ |l| l['attributes']['housing_request_id'] }.compact
        housing_offer_ids = datas.map{ |l| l['attributes']['housing_offer_id'] }.compact
        score_ids = datas.map{ |l| l['attributes']['score_id'] }.compact
        expect(housing_request_ids).to include(housing_request.id.to_s)
        expect(housing_offer_ids).not_to include(housing_offer.id.to_s)
        expect(score_ids).not_to include(score.id.to_s)
      end

      it 'should return only housing_offers logs' do
        get :housing_offers

        datas = json['data']
        housing_request_ids = datas.map{ |l| l['attributes']['housing_request_id'] }.compact
        housing_offer_ids = datas.map{ |l| l['attributes']['housing_offer_id'] }.compact
        score_ids = datas.map{ |l| l['attributes']['score_id'] }.compact
        expect(housing_request_ids).not_to include(housing_request.id.to_s)
        expect(housing_offer_ids).to include(housing_offer.id.to_s)
        expect(score_ids).not_to include(score.id.to_s)
      end

      it 'should return only scores logs' do
        get :scores

        datas = json['data']
        housing_request_ids = datas.map{ |l| l['attributes']['housing_request_id'] }.compact
        housing_offer_ids = datas.map{ |l| l['attributes']['housing_offer_id'] }.compact
        score_ids = datas.map{ |l| l['attributes']['score_id'] }.compact
        expect(housing_request_ids).not_to include(housing_request.id.to_s)
        expect(housing_offer_ids).not_to include(housing_offer.id.to_s)
        expect(score_ids).to include(score.id.to_s)
      end
    end

    describe 'show' do
      before(:each) do
        authenticated_header(request, admin)
      end
      
      it 'should return log' do
        get :show, id: score_log.id
        expect(json['data']['id']).to eq(score_log.id.to_s)
      end
    end
  end

  RSpec.describe Api::Dmo::LogsController, type: :request, swagger_doc: 'api/swagger/hermes/swagger_hermes.json' do
    require_relative '../../swagger_helper'
    TAGS_API_DMO_LOGS = 'API_DMO_LOGS'.freeze
    include JwtAuthHelper
    extend HermesSwaggerJsonParams
    include SwaggerJsonAttributes
    let!(:admin) { create(:user, auth_roles: ['superadministrateur']) }
    let!(:score) { create(:score) }
    let!(:score_log) { create(:h_log, code: 'SC_C', action: 'score action', score_id: score.id) }

    path '/api/dmo/logs' do
      get 'Retrieves all logs' do
        tags TAGS_API_DMO_LOGS
        produces 'application/json'
        
        parameter name: 'ids[]', in: :query, type: :array, items: {type: :string}, collectionFormat: :multi, required: false
        ACCEPTABLE_PARAMS.each do |acceptable_param|
          parameter name: acceptable_param.to_s, in: :query, type: :string, required: false
        end
        
        security [Bearer: {}]
        paginator
        
        response '200', 'logs found' do
          let(:Authorization) {"Bearer #{token_for(admin)}"}
          let!(:logs) {create_list(:h_log, 5)}
          
          include_context 'with integration test'
        end
      end
    end

    %w[housing_offers housing_requests scores applicants].each do |ressource|
      path "/api/dmo/logs/#{ressource}" do
        get "Retrieves all logs for #{ressource}" do
          tags TAGS_API_DMO_LOGS
          produces 'application/json'
          
          parameter name: 'ids[]', in: :query, type: :array, items: {type: :string}, collectionFormat: :multi, required: false
          ACCEPTABLE_PARAMS.each do |acceptable_param|
            parameter name: acceptable_param.to_s, in: :query, type: :string, required: false
          end
          
          security [Bearer: {}]
          paginator
          
          response '200', 'logs found' do
            let(:Authorization) {"Bearer #{token_for(admin)}"}
            let!(:logs) {create_list(:h_log, 5)}
            
            include_context 'with integration test'
          end
        end
      end
    end

    path '/api/dmo/logs/{id}' do
      get 'Retrieves a log' do
        tags TAGS_API_DMO_LOGS
        produces 'application/json'
        
        parameter name: :id, in: :path, type: :string, required: true
        
        security [Bearer: {}]
        paginator
        
        response '200', 'log found' do
          let(:Authorization) {"Bearer #{token_for(admin)}"}
          let!(:log) {create(:h_log)}
          let(:id) { log.id.to_s }
          
          include_context 'with integration test'
        end
      end
    end
  end
end

==> hermes-5.3.0.19.tar.gz: hermes-5.3.0.19/spec/apis/dmo/logs_spec.rb <==
require 'rails_helper'
require 'faker'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')

  ACCEPTABLE_PARAMS = Hermes::Api::Dmo::LogsController::ACCEPTABLE_PARAMS
  
  RSpec.describe Api::Dmo::LogsController, :type => :api do
    routes {Hermes::Engine.routes}
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper

    let!(:admin) { create(:user, auth_roles: ['superadministrateur']) }
    let!(:housing_offer) { create(:housing_offer) }
    let!(:housing_offer_log) { create(:h_log, code: 'SC_C', action: 'housing_offer action', housing_offer_id: housing_offer.id) }
    let!(:housing_request) { create(:active_request) }
    let!(:housing_request_log) { create(:h_log, code: 'SC_C', action: 'housing_request action', housing_request_id: housing_request.id) }

    describe 'index' do
      before(:each) do
        authenticated_header(request, admin)
      end

      it 'should return all logs' do
        get :index

        datas = json['data']
        housing_offer_ids = datas.map{ |l| l['attributes']['housing_offer_id'] }.compact
        housing_request_ids = datas.map{ |l| l['attributes']['housing_request_id'] }.compact
        expect(housing_offer_ids).to include(housing_offer.id.to_s)
        expect(housing_request_ids).to include(housing_request.id.to_s)
      end

      it 'should return only housing_requests logs' do
        get :housing_requests

        datas = json['data']
        housing_request_ids = datas.map{ |l| l['attributes']['housing_request_id'] }.compact
        housing_offer_ids = datas.map{ |l| l['attributes']['housing_offer_id'] }.compact
        expect(housing_request_ids).to include(housing_request.id.to_s)
        expect(housing_offer_ids).not_to include(housing_offer.id.to_s)
      end

      it 'should return only housing_offers logs' do
        get :housing_offers

        datas = json['data']
        housing_request_ids = datas.map{ |l| l['attributes']['housing_request_id'] }.compact
        housing_offer_ids = datas.map{ |l| l['attributes']['housing_offer_id'] }.compact
        expect(housing_request_ids).not_to include(housing_request.id.to_s)
        expect(housing_offer_ids).to include(housing_offer.id.to_s)
      end
    end
  end

  RSpec.describe Api::Dmo::LogsController, type: :request, swagger_doc: 'api/swagger/hermes/swagger_hermes.json' do
    require_relative '../../swagger_helper'
    TAGS_API_DMO_LOGS = 'API_DMO_LOGS'.freeze
    include JwtAuthHelper
    extend HermesSwaggerJsonParams
    include SwaggerJsonAttributes
    let!(:admin) { create(:user, auth_roles: ['superadministrateur']) }

    path '/api/dmo/logs' do
      get 'Retrieves all logs' do
        tags TAGS_API_DMO_LOGS
        produces 'application/json'
        
        parameter name: 'ids[]', in: :query, type: :array, items: {type: :string}, collectionFormat: :multi, required: false
        ACCEPTABLE_PARAMS.each do |acceptable_param|
          parameter name: acceptable_param.to_s, in: :query, type: :string, required: false
        end
        
        security [Bearer: {}]
        paginator
        
        response '200', 'logs found' do
          let(:Authorization) {"Bearer #{token_for(admin)}"}
          let!(:logs) {create_list(:h_log, 5)}
          
          include_context 'with integration test'
        end
      end
    end

    %w[housing_offers housing_requests applicants].each do |ressource|
      path "/api/dmo/logs/#{ressource}" do
        get "Retrieves all logs for #{ressource}" do
          tags TAGS_API_DMO_LOGS
          produces 'application/json'
          
          parameter name: 'ids[]', in: :query, type: :array, items: {type: :string}, collectionFormat: :multi, required: false
          ACCEPTABLE_PARAMS.each do |acceptable_param|
            parameter name: acceptable_param.to_s, in: :query, type: :string, required: false
          end
          
          security [Bearer: {}]
          paginator
          
          response '200', 'logs found' do
            let(:Authorization) {"Bearer #{token_for(admin)}"}
            let!(:logs) {create_list(:h_log, 5)}
            
            include_context 'with integration test'
          end
        end
      end
    end

    path '/api/dmo/logs/{id}' do
      get 'Retrieves a log' do
        tags TAGS_API_DMO_LOGS
        produces 'application/json'
        
        parameter name: :id, in: :path, type: :string, required: true
        
        security [Bearer: {}]
        paginator
        
        response '200', 'log found' do
          let(:Authorization) {"Bearer #{token_for(admin)}"}
          let!(:log) {create(:h_log)}
          let(:id) { log.id.to_s }
          
          include_context 'with integration test'
        end
      end
    end
  end
end
